@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -114,7 +114,7 @@ void SendLaterDialog::load(SendLater::SendLaterInfo *info)
     mSendLaterWidget->mRecurrence->setChecked(recurrence);
     slotRecurrenceClicked(recurrence);
     mSendLaterWidget->mRecurrenceValue->setValue(info->recurrenceEachValue());
-    mSendLaterWidget->mRecurrenceComboBox->setCurrentIndex((int)info->recurrenceUnit());
+    mSendLaterWidget->mRecurrenceComboBox->setCurrentIndex(static_cast<int>(info->recurrenceUnit()));
 }
 
 SendLater::SendLaterInfo *SendLaterDialog::info()
@@ -124,7 +124,7 @@ SendLater::SendLaterInfo *SendLaterDialog::info()
     }
     mInfo->setRecurrence(mSendLaterWidget->mRecurrence->isChecked());
     mInfo->setRecurrenceEachValue(mSendLaterWidget->mRecurrenceValue->value());
-    mInfo->setRecurrenceUnit((SendLater::SendLaterInfo::RecurrenceUnit)mSendLaterWidget->mRecurrenceComboBox->currentIndex());
+    mInfo->setRecurrenceUnit(static_cast<SendLater::SendLaterInfo::RecurrenceUnit>(mSendLaterWidget->mRecurrenceComboBox->currentIndex()));
     if (mSendDateTime.isValid()) {
         mInfo->setDateTime(mSendDateTime);
     } else {
